# Classification

::: sleepecg.evaluate
::: sleepecg.list_classifiers
::: sleepecg.load_classifier
::: sleepecg.prepare_data_keras
::: sleepecg.print_class_balance
::: sleepecg.save_classifier
::: sleepecg.stage
::: sleepecg.SleepClassifier
